import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleTime,
  area,
  curveBasis,
  max,
  format

} from 'd3';

  const svg = select('svg');
  const width = +svg.attr('width');
  const height = +svg.attr('height');

  const render = data => {
  const xValue = d =>  d.year;
  const xAxisLabel = 'Year'
  const yValue = d =>  d.population ;
  const yAxisLabel = 'Population'
  
  const margin = { top: 100, right: 40, bottom: 80, left: 200 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 5;
  const title = 'World Population';
 
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain([0,max(data, yValue)])
    .range([innerHeight,0]);
 
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

    
  const yAxisTickFormat = number =>
    format('.1s')(number)
      .replace('G', 'B'); 
    
  const xAxis = axisBottom(xScale)
    
    .tickSize(-innerHeight)
    .tickPadding(15)
    .ticks(6);
   
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(yAxisTickFormat);
  
  g.append('g')
    .call(yAxis)
    .selectAll('.domain')
      .remove();
 
 
    
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove(); 
 
  xAxisG.append('text')
    .attr('class','xAxis-label')
    .text(xAxisLabel)
    .attr('fill','black')
    .attr('x',innerWidth/2)
    .attr('y',70)

     
  yAxisG.append('text')
    .attr('class','yAxis-label')
    .text(yAxisLabel)
    .attr('fill','black')
    .attr('x',-150)
    .attr('y',-50)
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle');
 
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d =>  yScale(yValue(d)))
    .curve(curveBasis);
  
  g.append('path') 
    .attr('d', areaGenerator(data))
    .attr('class','line-path'); 
   
  
  svg.append('text')
    .attr('class','title')
    .attr('x',width/2)
    .attr('y',40)
    .text(title)
    

   
};  



csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv')
  .then(data => {
  data.forEach(d => {
     d.population = +d.population; 
     d.year = new Date(d.year);  
     }); 
  render(data);
});